@@ -1,9 +1,11 @@
 package Javonet::Core::Handler::CommandHandler::CastingHandler;
 use strict;
-use Moose;
-use lib 'lib';
 use warnings FATAL => 'all';
+use lib 'lib';
+use Moose;
+use Nice::Try;
 use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
+extends 'Javonet::Core::Handler::CommandHandler::AbstractCommandHandler';
 
 sub new {
     my $class = shift;
