@@ -2,7 +2,7 @@ package Javonet::Core::Transmitter::PerlTransmitter;
 use strict;
 use warnings;
 use Cwd;
-use aliased 'Javonet::Core::Transmitter::PerlTransmitterWrapper' => 'PerlTransmitterWrapper' , qw(send_command activate);
+use aliased 'Javonet::Core::Transmitter::PerlTransmitterWrapper' => 'PerlTransmitterWrapper' , qw(send_command activate set_config_source set_javonet_working_directory);
 
 sub send_command {
     my ($self, $message_byte_array_ref) = @_;
@@ -20,4 +20,9 @@ sub set_config_source {
     PerlTransmitterWrapper->set_config_source($config_path);
 }
 
+sub set_javonet_working_directory {
+    my ($self, $working_directory) = @_;
+    PerlTransmitterWrapper->set_javonet_working_directory($working_directory);
+}
+
 1;
