@@ -1,11 +1,7 @@
 package Javonet::Sdk::Core::StringEncodingMode;
 use strict;
 use warnings;
-use Exporter;
-
-our @ISA = qw(Exporter);
-our @EXPORT = qw(get_string_encoding_mode);
-
+use Moose;
 
 my %string_encoding_mode = (
     'ASCII'             => 0,
@@ -19,4 +15,6 @@ sub get_string_encoding_mode {
     return $string_encoding_mode{$mode};
 }
 
+no Moose;
+
 1;
\ No newline at end of file
